@@ -38,7 +38,6 @@
 
 #include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
-#include <gnome-keyring-memory.h>
 
 #define NM_VPN_API_SUBJECT_TO_CHANGE
 
@@ -1297,6 +1296,24 @@ decrypt_cisco_key (const char* enc_key)
 	return key;
 }
 
+typedef enum {
+	NM_VPNC_IMPORT_EXPORT_ERROR_UNKNOWN = 0,
+	NM_VPNC_IMPORT_EXPORT_ERROR_NOT_VPNC,
+	NM_VPNC_IMPORT_EXPORT_ERROR_BAD_DATA,
+} NMVpncImportError;
+
+#define NM_VPNC_IMPORT_EXPORT_ERROR nm_vpnc_import_export_error_quark ()
+
+static GQuark
+nm_vpnc_import_export_error_quark (void)
+{
+	static GQuark quark = 0;
+
+	if (G_UNLIKELY (quark == 0))
+		quark = g_quark_from_static_string ("nm-vpnc-import-export-error-quark");
+	return quark;
+}
+
 static NMConnection *
 import (NMVpnPluginUiInterface *iface, const char *path, GError **error)
 {
@@ -1312,11 +1329,8 @@ import (NMVpnPluginUiInterface *iface, const char *path, GError **error)
 	gboolean found;
 
 	keyfile = g_key_file_new ();
-	if (!g_key_file_load_from_file (keyfile, path, 0, error)) {
-		g_set_error (error, 0, 0, "does not look like a %s VPN connection (parse failed)",
-		             VPNC_PLUGIN_NAME);
+	if (!g_key_file_load_from_file (keyfile, path, 0, error))
 		goto error;
-	}
 
 	connection = nm_connection_new ();
 	s_con = NM_SETTING_CONNECTION (nm_setting_connection_new ());
@@ -1335,7 +1349,10 @@ import (NMVpnPluginUiInterface *iface, const char *path, GError **error)
 		nm_setting_vpn_add_data_item (s_vpn, NM_VPNC_KEY_GATEWAY, buf);
 		g_free (buf);
 	} else {
-		g_set_error (error, 0, 0, "does not look like a %s VPN connection (no Host)",
+		g_set_error (error,
+		             NM_VPNC_IMPORT_EXPORT_ERROR,
+		             NM_VPNC_IMPORT_EXPORT_ERROR_NOT_VPNC,
+		             "does not look like a %s VPN connection (no Host)",
 		             VPNC_PLUGIN_NAME);
 		goto error;
 	}
@@ -1346,7 +1363,10 @@ import (NMVpnPluginUiInterface *iface, const char *path, GError **error)
 		nm_setting_vpn_add_data_item (s_vpn, NM_VPNC_KEY_ID, buf);
 		g_free (buf);
 	} else {
-		g_set_error (error, 0, 0, "does not look like a %s VPN connection (no GroupName)",
+		g_set_error (error,
+		             NM_VPNC_IMPORT_EXPORT_ERROR,
+		             NM_VPNC_IMPORT_EXPORT_ERROR_BAD_DATA,
+		             "does not look like a %s VPN connection (no GroupName)",
 		             VPNC_PLUGIN_NAME);
 		goto error;
 	}
@@ -1587,7 +1607,10 @@ export (NMVpnPluginUiInterface *iface,
 
 	f = fopen (path, "w");
 	if (!f) {
-		g_set_error (error, 0, 0, "could not open file for writing");
+		g_set_error_literal (error,
+		                     NM_VPNC_IMPORT_EXPORT_ERROR,
+		                     NM_VPNC_IMPORT_EXPORT_ERROR_UNKNOWN,
+		                     "could not open file for writing");
 		return FALSE;
 	}
 
@@ -1595,7 +1618,10 @@ export (NMVpnPluginUiInterface *iface,
 	if (value && strlen (value))
 		gateway = value;
 	else {
-		g_set_error (error, 0, 0, "connection was incomplete (missing gateway)");
+		g_set_error_literal (error,
+		                     NM_VPNC_IMPORT_EXPORT_ERROR,
+		                     NM_VPNC_IMPORT_EXPORT_ERROR_BAD_DATA,
+		                     "connection was incomplete (missing gateway)");
 		goto done;
 	}
 
@@ -1603,7 +1629,10 @@ export (NMVpnPluginUiInterface *iface,
 	if (value && strlen (value))
 		groupname = value;
 	else {
-		g_set_error (error, 0, 0, "connection was incomplete (missing group)");
+		g_set_error_literal (error,
+		                     NM_VPNC_IMPORT_EXPORT_ERROR,
+		                     NM_VPNC_IMPORT_EXPORT_ERROR_BAD_DATA,
+		                     "connection was incomplete (missing group)");
 		goto done;
 	}
 
